@@ -125,7 +125,7 @@ int context_map_set_cnlink(struct hnbgw_context_map *map, struct hnbgw_cnlink *c
 
 	hash_add(hsu->hnbgw_context_map_by_conn_id, &map->hnbgw_sccp_user_entry, new_scu_conn_id);
 
-	LOGP(DRUA, LOGL_INFO, "New conn: %s '%s' RUA-%u <-> SCCP-%u %s%s%s %s l=%s<->r=%s\n",
+	LOGP(DRUA, LOGL_NOTICE, "New conn: %s '%s' RUA-%u <-> SCCP-%u %s%s%s %s l=%s<->r=%s\n",
 	     osmo_sock_get_name2_c(OTC_SELECT, osmo_stream_srv_get_ofd(map->hnb_ctx->conn)->fd),
 	     hnb_context_name(map->hnb_ctx), map->rua_ctx_id,
 	     new_scu_conn_id,
@@ -186,7 +186,7 @@ void context_map_hnb_released(struct hnbgw_context_map *map)
 
 void context_map_cnlink_lost(struct hnbgw_context_map *map)
 {
-	map_sccp_dispatch(map, MAP_SCCP_EV_CN_LINK_LOST, NULL);
+	map_sccp_dispatch(map, MAP_SCCP_EV_RAN_LINK_LOST, NULL);
 }
 
 void context_map_free(struct hnbgw_context_map *map)
